==> hugegraph-client-1.9.0-sources.jar: com/baidu/hugegraph/structure/constant/Traverser.java <==
/*
 * Copyright 2017 HugeGraph Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package com.baidu.hugegraph.structure.constant;

public class Traverser {

    public static final long DEFAULT_CAPACITY = 10_000_000L;
    public static final long DEFAULT_LIMIT = 100L;
    public static final long DEFAULT_ELEMENTS_LIMIT = 10_000_000L;
    public static final long DEFAULT_DEGREE = 10_000L;
    public static final long DEFAULT_CROSSPOINT_LIMIT = 10_000L;
    public static final long DEFAULT_PATHS_LIMIT = 10L;
    public static final long DEFAULT_DEDUP_SIZE = 1_000_000L;
    public static final long DEFAULT_SKIP_DEGREE = 100_000L;
    public static final long DEFAULT_SAMPLE = 100L;
    public static final double DEFAULT_WEIGHT = 0.0D;
    public static final long DEFAULT_PAGE_LIMIT = 100_000L;
    public static final double DEFAULT_ALPHA = 0.9;
    public static final int DEFAULT_MAX_TOP = 1000;
    public static final int DEFAULT_MAX_DEPTH = 50;
}

==> hugegraph-client-2.0.1-sources.jar: com/baidu/hugegraph/structure/constant/Traverser.java <==
/*
 * Copyright 2017 HugeGraph Authors
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package com.baidu.hugegraph.structure.constant;

public class Traverser {

    public static final long DEFAULT_CAPACITY = 10_000_000L;
    public static final long DEFAULT_LIMIT = 100L;
    public static final long DEFAULT_ELEMENTS_LIMIT = 10_000_000L;
    public static final long DEFAULT_MAX_DEGREE = 10_000L;
    public static final long DEFAULT_CROSSPOINT_LIMIT = 10_000L;
    public static final long DEFAULT_PATHS_LIMIT = 10L;
    public static final long DEFAULT_DEDUP_SIZE = 1_000_000L;
    public static final long DEFAULT_SKIP_DEGREE = 100_000L;
    public static final long DEFAULT_SAMPLE = 100L;
    public static final double DEFAULT_WEIGHT = 0.0D;
    public static final long DEFAULT_PAGE_LIMIT = 100_000L;
    public static final double DEFAULT_ALPHA = 0.9;
    public static final int DEFAULT_MAX_TOP = 1000;
    public static final int DEFAULT_MAX_DEPTH = 50;
}
